@@ -37,6 +37,15 @@ class GraphController:
         for node_name in node_names:
             node = ModuleNode.from_str(node_name)
             self.graph.remove_node(node)
+            self.graph.remove_cluster(node)
+        return self
+
+    def focus(self, node_name: str, *extra_node_names: str) -> "GraphController":
+        node = ModuleNode.from_str(node_name)
+        extra_nodes = [ModuleNode.from_str(name) for name in extra_node_names]
+
+        self.graph.focus_nodes_and_clusters(node, *extra_nodes)
+
         return self
 
     def dig(self, *node_names: str) -> "GraphController":
@@ -96,3 +105,20 @@ class GraphController:
 
         # graphvizの実装に移譲する
         return g._repr_svg_()
+
+    @dataclasses.dataclass
+    class DigraphDot:
+        graph: Digraph
+
+        def __str__(self) -> str:
+            return str(self.graph)
+
+        def _repr_markdown_(self):
+            """
+            Jupyter 上でオブジェクト自身を評価した時マークダウンとして解釈・描画されるようにする。
+            :return:
+            """
+            return f"```\n{self.graph}\n```"
+
+    def render_dot(self) -> "DigraphDot":
+        return self.DigraphDot(self.render())
